==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/config/lang/fi/lang.php <==
<?php
/**
 * Finnish language file
 *
 * @author otto@valjakko.net
 */
$lang['menu']                  = 'Asetukset';
$lang['error']                 = 'Asetuksia ei päivitetty väärän arvon vuoksi. Tarkista muutokset ja lähetä sivu uudestaan.
<br />Väärät arvot on merkitty punaisella reunuksella.';
$lang['updated']               = 'Asetukset päivitetty onnistuneesti.';
$lang['nochoice']              = '(ei muita valintoja saatavilla)';
$lang['locked']                = 'Asetustiedostia ei voi päivittää. Jos tämä ei oel tarkoitus, <br />
niin varmista, että paikallisten asetusten tiedoston nimi ja oikeudet ovat kunnossa.';
$lang['_configuration_manager'] = 'Asetusten hallinta';
$lang['_header_dokuwiki']      = 'DokuWikin asetukset';
$lang['_header_plugin']        = 'Liitännäisten asetukset';
$lang['_header_template']      = 'Sivumallin asetukset';
$lang['_header_undefined']     = 'Määrittelettömät asetukset';
$lang['_basic']                = 'Perusasetukset';
$lang['_display']              = 'Näyttöasetukset';
$lang['_authentication']       = 'Sisääkirjoittautumisen asetukset';
$lang['_anti_spam']            = 'Anti-Spam asetukset';
$lang['_editing']              = 'Sivumuokkauksen asetukset';
$lang['_links']                = 'Linkkien asetukset';
$lang['_media']                = 'Media-asetukset';
$lang['_advanced']             = 'Lisäasetukset';
$lang['_network']              = 'Verkkoasetukset';
$lang['_plugin_sufix']         = 'Liitännäisten asetukset';
$lang['_template_sufix']       = 'Sivumallin asetukset';
$lang['_msg_setting_undefined'] = 'Ei asetusten metadataa.';
$lang['_msg_setting_no_class'] = 'Ei asetusluokkaa.';
$lang['_msg_setting_no_default'] = 'Ei oletusarvoa';
$lang['fmode']                 = 'Tiedoston luontioikeudet';
$lang['dmode']                 = 'Hakemiston luontioikeudet';
$lang['lang']                  = 'Kieli';
$lang['basedir']               = 'Peruhakemisto';
$lang['baseurl']               = 'Perus URL';
$lang['savedir']               = 'Hakemisto tietojen tallennukseen.';
$lang['start']                 = 'Alkusivun nimi';
$lang['title']                 = 'Wikin nimi';
$lang['template']              = 'Sivumalli';
$lang['fullpath']              = 'Näytä sivun koko polku sivun alareunassa';
$lang['recent']                = 'Viimemuutokset';
$lang['breadcrumbs']           = 'Leivänmurujen määrä';
$lang['youarehere']            = 'Hierarkiset leivänmurut';
$lang['typography']            = 'Tee typograafiset korvaukset';
$lang['htmlok']                = 'Salli upotettu HTML';
$lang['phpok']                 = 'Salli upotettu PHP';
$lang['dformat']               = 'Päivämäärän muoto (katso PHPn <a href="http://www.php.net/strftime">strftime</a> functiota)';
$lang['signature']             = 'Allekirjoitus';
$lang['toptoclevel']           = 'Ylätason sisällysluettelo';
$lang['maxtoclevel']           = 'Sisällysluettelon suurin syvyys';
$lang['maxseclevel']           = 'Kappale-editoinnin suurin syvyys.';
$lang['camelcase']             = 'Käytä CamelCase linkkejä';
$lang['deaccent']              = 'Siivoa sinun nimet';
$lang['useheading']            = 'Käytä ensimmäistä otsikkoriviä sinun nimenä.';
$lang['refcheck']              = 'Median viitteen tarkistus';
$lang['refshow']               = 'Montako media viitettä näytetään';
$lang['allowdebug']            = 'Salli debuggaus <b>pois, jos ei tarvita!</b>';
$lang['usewordblock']          = 'Estä spam sanalistan avulla';
$lang['indexdelay']            = 'Aikaraja indeksoinnille (sek)';
$lang['relnofollow']           = 'Käytä rel="nofollow" ukoisille linkeille';
$lang['mailguard']             = 'Häivytä email osoite';
$lang['iexssprotect']          = 'Tarkista lähetetyt tiedostot pahojen javascript- ja html-koodien varalta';
$lang['useacl']                = 'Käytä käyttöoikeuksien hallintaa';
$lang['autopasswd']            = 'Luo salasana automaattisesti';
$lang['authtype']              = 'Autentikointijärjestelmä';
$lang['passcrypt']             = 'Salasanan suojausmenetelmä';
$lang['defaultgroup']          = 'Oletusryhmä';
$lang['superuser']             = 'Pääkäyttäjä. Ryhmä tai käyttäjä, jolla on täysi oikeus kaikkiin sivuihin ja toimintoihin käyttöoikeuksista huolimatta';
$lang['manager']               = 'Ylläpitäjä. Ryhmä tai käyttäjä, jolla on pääsy joihinkin ylläpitotoimintoihin';
$lang['profileconfirm']        = 'Vahvista profiilin päivitys salasanan avulla';
$lang['disableactions']        = 'Estä DokuWiki toimintojen käyttö';
$lang['disableactions_check']  = 'Tarkista';
$lang['disableactions_subscription'] = 'Tilaa/Peruuta tilaus';
$lang['disableactions_wikicode'] = 'Näytä lähdekoodi/Vie raakana';
$lang['disableactions_other']  = 'Muut toiminnot (pilkulla erotettuna)';
$lang['sneaky_index']          = 'Oletuksena DokuWiki näyttää kaikki nimiavaruudet index-näkymäsä. Tämä asetus piilottaa ne, joihin käyttäjällä ei ole lukuoikeuksia. Tämä voi piilottaa joitakin sallittuja ali-nimiavaruuksia. Tästä johtuen index-näkymä voi olla käyttöklvoton joillakin ACL-asetuksilla';
$lang['updatecheck']           = 'Tarkista päivityksiä ja turvavaroituksia? Tätä varten DokuWikin pitää ottaa yhteys splitbrain.orgiin.';
$lang['userewrite']            = 'Käytä siivottuja URLeja';
$lang['useslash']              = 'Käytä kauttaviivaa nimiavaruuksien erottimena URL-osoitteissa';
$lang['usedraft']              = 'Automaattisesti tallenna vedos muokkautilassa';
$lang['sepchar']               = 'Sivunimen sanaerotin';
$lang['autoplural']            = 'Etsi monikkomuotoja linkeistä';
$lang['compression']           = 'Attic tiedostojen pakkausmenetelmä';
$lang['cachetime']             = 'Välimuisti-tiedostojen maksimi-ikä (sek)';
$lang['locktime']              = 'Lukitustiedostojen maksimi-ikä (sek)';
$lang['fetchsize']             = 'Suurin koko (bytejä), jonka fetch.php voi ladata ulkopuolisesta lähteestä';
$lang['notify']                = 'Lähetä muutos ilmoitukset tähän osoitteeseen';
$lang['registernotify']        = 'Lähetä ilmoitus uusista rekisteröitymisistä tähän osoitteeseen';
$lang['mailfrom']              = 'Sähköpostiosoite automaattisia postituksia varten';
$lang['gzip_output']           = 'Käytä gzip "Content.Encoding" tapaa xhtml varten';
$lang['gdlib']                 = 'GD Lib versio';
$lang['im_convert']            = 'ImageMagick muunnostyökalun polku';
$lang['jpg_quality']           = 'JPG pakkauslaatu';
$lang['subscribers']           = 'Salli tuki sivujen tilaamiselle';
$lang['compress']              = 'Pakkaa CSS ja javascript';
$lang['hidepages']             = 'Piilota seuraavat sivut (säännönmukainen lauseke)';
$lang['send404']               = 'Lähetä "HTTP 404/Page Not Found" puuttuvista sivuista';
$lang['sitemap']               = 'Luo Google sitemap (päiviä)';
$lang['broken_iua']            = 'Onko "ignore_user_abort" toiminto rikki systeemissäsi. Tämä voi aiheuttaa toimimattoman index-näkymän.
IIS+PHP/CGI on tunnetusti rikki. Katso <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> lisätietoja varten.';
$lang['xsendfile']             = 'Käytä X-Sendfile otsikkoa, kun web-palvelin lähettää staattisia tiedostoja? Palvelimesi pitää tukea tätä.';
$lang['rss_type']              = 'XML-syötteen tyyppi';
$lang['rss_linkto']            = 'XML-syöte kytkeytyy';
$lang['rss_content']           = 'Mikä XML-syöte näyttää?';
$lang['rss_update']            = 'XML-syötteen päivitystahti (sek)';
$lang['recent_days']           = 'Montako edellistä muutosta säilytetään (päiviä)';
$lang['rss_show_summary']      = 'XML-syöte näyttää yhteenvedon otsikossa';
$lang['target____wiki']        = 'Kohdeikkuna sisäisissä linkeissä';
$lang['target____interwiki']   = 'Kohdeikkuna interwiki-linkeissä';
$lang['target____extern']      = 'Kohdeikkuna ulkoisissa linkeissä';
$lang['target____media']       = 'Kohdeikkuna media-linkeissä';
$lang['target____windows']     = 'Kohdeikkuna Windows-linkeissä';
$lang['proxy____host']         = 'Proxy-palvelimen nimi';
$lang['proxy____port']         = 'Proxy portti';
$lang['proxy____user']         = 'Proxy käyttäjän nimi';
$lang['proxy____pass']         = 'Proxy salasana';
$lang['proxy____ssl']          = 'Käytä ssl-yhteyttä kytkeytyäksesi proxy-palvelimeen';
$lang['safemodehack']          = 'Käytä safemode kiertoa';
$lang['ftp____host']           = 'FTP-palvelin safemode kiertoa varten';
$lang['ftp____port']           = 'FTP-portti safemode kiertoa varten';
$lang['ftp____user']           = 'FTP-käyttäjä safemode kiertoa varten';
$lang['ftp____pass']           = 'FTP-salasana safemode kiertoa varten';
$lang['ftp____root']           = 'FTP-juurihakemisto safemode kiertoa varten';
$lang['typography_o_0']        = 'ei mitään';
$lang['typography_o_1']        = 'Vain tupla lainaukset';
$lang['typography_o_2']        = 'kaikki lainaukset';
$lang['userewrite_o_0']        = 'ei mitään';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'DokuWikin sisäinen';
$lang['deaccent_o_0']          = 'pois';
$lang['deaccent_o_1']          = 'Poista aksenttimerkit';
$lang['deaccent_o_2']          = 'translitteroi';
$lang['gdlib_o_0']             = 'GD Lib ei ole saatavilla';
$lang['gdlib_o_1']             = 'Versio 1.x';
$lang['gdlib_o_2']             = 'Automaattitunnistus';
$lang['rss_content_o_abstract'] = 'Yhteenveto';
$lang['rss_content_o_html']    = 'Täysi HTML-sivu';
$lang['rss_linkto_o_diff']     = 'erot-näkymä';
$lang['rss_linkto_o_page']     = 'muutettu sivu';
$lang['rss_linkto_o_rev']      = 'versiolista';
$lang['rss_linkto_o_current']  = 'nykyinen sivu';
$lang['compression_o_0']       = 'ei mitään';
$lang['xsendfile_o_0']         = 'älä käytä';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/config/lang/fi/lang.php <==
<?php
/**
 * Finnish language file
 *
 * @author otto@valjakko.net
 * @author Otto Vainio <otto@valjakko.net>
 */
$lang['menu']                  = 'Asetukset';
$lang['error']                 = 'Asetuksia ei päivitetty väärän arvon vuoksi. Tarkista muutokset ja lähetä sivu uudestaan.
<br />Väärät arvot on merkitty punaisella reunuksella.';
$lang['updated']               = 'Asetukset päivitetty onnistuneesti.';
$lang['nochoice']              = '(ei muita valintoja saatavilla)';
$lang['locked']                = 'Asetustiedosta ei voi päivittää. Jos tämä ei ole tarkoitus, <br />
niin varmista, että paikallisten asetusten tiedoston nimi ja oikeudet ovat kunnossa.';
$lang['_configuration_manager'] = 'Asetusten hallinta';
$lang['_header_dokuwiki']      = 'DokuWikin asetukset';
$lang['_header_plugin']        = 'Liitännäisten asetukset';
$lang['_header_template']      = 'Sivumallin asetukset';
$lang['_header_undefined']     = 'Määritetelettömät asetukset';
$lang['_basic']                = 'Perusasetukset';
$lang['_display']              = 'Näyttöasetukset';
$lang['_authentication']       = 'Sisäänkirjoittautumisen asetukset';
$lang['_anti_spam']            = 'Anti-Spam asetukset';
$lang['_editing']              = 'Sivumuokkauksen asetukset';
$lang['_links']                = 'Linkkien asetukset';
$lang['_media']                = 'Media-asetukset';
$lang['_advanced']             = 'Lisäasetukset';
$lang['_network']              = 'Verkkoasetukset';
$lang['_plugin_sufix']         = 'Liitännäisten asetukset';
$lang['_template_sufix']       = 'Sivumallin asetukset';
$lang['_msg_setting_undefined'] = 'Ei asetusten metadataa.';
$lang['_msg_setting_no_class'] = 'Ei asetusluokkaa.';
$lang['_msg_setting_no_default'] = 'Ei oletusarvoa';
$lang['fmode']                 = 'Tiedoston luontioikeudet';
$lang['dmode']                 = 'Hakemiston luontioikeudet';
$lang['lang']                  = 'Kieli';
$lang['basedir']               = 'Peruhakemisto';
$lang['baseurl']               = 'Perus URL';
$lang['savedir']               = 'Hakemisto tietojen tallennukseen.';
$lang['start']                 = 'Alkusivun nimi';
$lang['title']                 = 'Wikin nimi';
$lang['template']              = 'Sivumalli';
$lang['license']               = 'Millä lisenssillä sisältö pitäisi julkaista?';
$lang['fullpath']              = 'Näytä sivun koko polku sivun alareunassa';
$lang['recent']                = 'Viime muutokset';
$lang['breadcrumbs']           = 'Leivänmurujen määrä';
$lang['youarehere']            = 'Hierarkkiset leivänmurut';
$lang['typography']            = 'Tee typografiset korvaukset';
$lang['htmlok']                = 'Salli upotettu HTML';
$lang['phpok']                 = 'Salli upotettu PHP';
$lang['dformat']               = 'Päivämäärän muoto (katso PHPn <a href="http://www.php.net/strftime">strftime</a> funktiota)';
$lang['signature']             = 'Allekirjoitus';
$lang['toptoclevel']           = 'Ylätason sisällysluettelo';
$lang['tocminheads']           = 'Pienin otsikkorivien määrä, jotta sisällysluettelo tehdään';
$lang['maxtoclevel']           = 'Sisällysluettelon suurin syvyys';
$lang['maxseclevel']           = 'Kappale-editoinnin suurin syvyys.';
$lang['camelcase']             = 'Käytä CamelCase linkkejä';
$lang['deaccent']              = 'Siivoa sivun nimet';
$lang['useheading']            = 'Käytä ensimmäistä otsikkoriviä sivun nimenä.';
$lang['refcheck']              = 'Median viitteen tarkistus';
$lang['refshow']               = 'Montako media viitettä näytetään';
$lang['allowdebug']            = 'Salli debuggaus <b>pois, jos ei tarvita!</b>';
$lang['usewordblock']          = 'Estä spam sanalistan avulla';
$lang['indexdelay']            = 'Aikaraja indeksoinnille (sek)';
$lang['relnofollow']           = 'Käytä rel="nofollow" ulkoisille linkeille';
$lang['mailguard']             = 'Häivytä email osoite';
$lang['iexssprotect']          = 'Tarkista lähetetyt tiedostot pahojen javascript- ja html-koodien varalta';
$lang['showuseras']            = 'Mitä näytetään, kun kerrotaan viimeisen editoijan tiedot';
$lang['useacl']                = 'Käytä käyttöoikeuksien hallintaa';
$lang['autopasswd']            = 'Luo salasana automaattisesti';
$lang['authtype']              = 'Autentikointijärjestelmä';
$lang['passcrypt']             = 'Salasanan suojausmenetelmä';
$lang['defaultgroup']          = 'Oletusryhmä';
$lang['superuser']             = 'Pääkäyttäjä. Ryhmä tai käyttäjä, jolla on täysi oikeus kaikkiin sivuihin ja toimintoihin käyttöoikeuksista huolimatta';
$lang['manager']               = 'Ylläpitäjä. Ryhmä tai käyttäjä, jolla on pääsy joihinkin ylläpitotoimintoihin';
$lang['profileconfirm']        = 'Vahvista profiilin päivitys salasanan avulla';
$lang['disableactions']        = 'Estä DokuWiki toimintojen käyttö';
$lang['disableactions_check']  = 'Tarkista';
$lang['disableactions_subscription'] = 'Tilaa/Peruuta tilaus';
$lang['disableactions_nssubscription'] = 'Nimiavaruuden tilaus/tilauksen poisto';
$lang['disableactions_wikicode'] = 'Näytä lähdekoodi/Vie raakana';
$lang['disableactions_other']  = 'Muut toiminnot (pilkulla erotettuna)';
$lang['sneaky_index']          = 'Oletuksena DokuWiki näyttää kaikki nimiavaruudet index-näkymäsä. Tämä asetus piilottaa ne, joihin käyttäjällä ei ole lukuoikeuksia. Tämä voi piilottaa joitakin sallittuja ali-nimiavaruuksia. Tästä johtuen index-näkymä voi olla käyttökelvoton joillakin ACL-asetuksilla';
$lang['auth_security_timeout'] = 'Autentikoinnin aikakatkaisu (sekunteja)';
$lang['securecookie']          = 'Lähetetäänkö HTTPS kautta asetetut cookies tiedot HTTPS yhdeydellä? Kytke pois, jos vain kirjautuminen wikisi on suojattu SSL:n avulla, mutta muuten wikiä käytetään ilman suojausta.';
$lang['updatecheck']           = 'Tarkista päivityksiä ja turvavaroituksia? Tätä varten DokuWikin pitää ottaa yhteys splitbrain.orgiin.';
$lang['userewrite']            = 'Käytä siivottuja URLeja';
$lang['useslash']              = 'Käytä kauttaviivaa nimiavaruuksien erottimena URL-osoitteissa';
$lang['usedraft']              = 'Automaattisesti tallenna vedos muokkaustilassa';
$lang['sepchar']               = 'Sivunimen sanaerotin';
$lang['canonical']             = 'Käytä "Canonical URL"';
$lang['autoplural']            = 'Etsi monikkomuotoja linkeistä';
$lang['compression']           = 'Attic tiedostojen pakkausmenetelmä';
$lang['cachetime']             = 'Välimuisti-tiedostojen maksimi-ikä (sek)';
$lang['locktime']              = 'Lukitustiedostojen maksimi-ikä (sek)';
$lang['fetchsize']             = 'Suurin koko (bytejä), jonka fetch.php voi ladata ulkopuolisesta lähteestä';
$lang['notify']                = 'Lähetä muutos ilmoitukset tähän osoitteeseen';
$lang['registernotify']        = 'Lähetä ilmoitus uusista rekisteröitymisistä tähän osoitteeseen';
$lang['mailfrom']              = 'Sähköpostiosoite automaattisia postituksia varten';
$lang['gzip_output']           = 'Käytä gzip "Content.Encoding" tapaa xhtml varten';
$lang['gdlib']                 = 'GD Lib versio';
$lang['im_convert']            = 'ImageMagick muunnostyökalun polku';
$lang['jpg_quality']           = 'JPG pakkauslaatu';
$lang['subscribers']           = 'Salli tuki sivujen tilaamiselle';
$lang['compress']              = 'Pakkaa CSS ja javascript';
$lang['hidepages']             = 'Piilota seuraavat sivut (säännönmukainen lauseke)';
$lang['send404']               = 'Lähetä "HTTP 404/Page Not Found" puuttuvista sivuista';
$lang['sitemap']               = 'Luo Google sitemap (päiviä)';
$lang['broken_iua']            = 'Onko "ignore_user_abort" toiminto rikki systeemissäsi. Tämä voi aiheuttaa toimimattoman index-näkymän.
IIS+PHP/CGI on tunnetusti rikki. Katso <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> lisätietoja varten.';
$lang['xsendfile']             = 'Käytä X-Sendfile otsikkoa, kun web-palvelin lähettää staattisia tiedostoja? Palvelimesi pitää tukea tätä.';
$lang['xmlrpc']                = 'Käytä/poista XML-RPC liityntää';
$lang['renderer_xhtml']        = 'Renderöinti, jota käytetään wikin pääasialliseen (xhtml) outputtiin';
$lang['renderer__core']        = '%s (dokuwiki core)';
$lang['renderer__plugin']      = '%s (liitännäinen)';
$lang['rememberme']            = 'Salli pysyvät kirjautumis-cookiet (muista minut)';
$lang['rss_type']              = 'XML-syötteen tyyppi';
$lang['rss_linkto']            = 'XML-syöte kytkeytyy';
$lang['rss_content']           = 'Mitä XML-syöte näyttää?';
$lang['rss_update']            = 'XML-syötteen päivitystahti (sek)';
$lang['recent_days']           = 'Montako edellistä muutosta säilytetään (päiviä)';
$lang['rss_show_summary']      = 'XML-syöte näyttää yhteenvedon otsikossa';
$lang['target____wiki']        = 'Kohdeikkuna sisäisissä linkeissä';
$lang['target____interwiki']   = 'Kohdeikkuna interwiki-linkeissä';
$lang['target____extern']      = 'Kohdeikkuna ulkoisissa linkeissä';
$lang['target____media']       = 'Kohdeikkuna media-linkeissä';
$lang['target____windows']     = 'Kohdeikkuna Windows-linkeissä';
$lang['proxy____host']         = 'Proxy-palvelimen nimi';
$lang['proxy____port']         = 'Proxy portti';
$lang['proxy____user']         = 'Proxy käyttäjän nimi';
$lang['proxy____pass']         = 'Proxy salasana';
$lang['proxy____ssl']          = 'Käytä ssl-yhteyttä kytkeytyäksesi proxy-palvelimeen';
$lang['safemodehack']          = 'Käytä safemode kiertoa';
$lang['ftp____host']           = 'FTP-palvelin safemode kiertoa varten';
$lang['ftp____port']           = 'FTP-portti safemode kiertoa varten';
$lang['ftp____user']           = 'FTP-käyttäjä safemode kiertoa varten';
$lang['ftp____pass']           = 'FTP-salasana safemode kiertoa varten';
$lang['ftp____root']           = 'FTP-juurihakemisto safemode kiertoa varten';
$lang['license_o_']            = 'ei mitään valittuna';
$lang['typography_o_0']        = 'ei mitään';
$lang['typography_o_1']        = 'paitsi yksinkertaiset lainausmerkit';
$lang['typography_o_2']        = 'myös yksinkertaiset lainausmerkit (ei aina toimi)';
$lang['userewrite_o_0']        = 'ei mitään';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'DokuWikin sisäinen';
$lang['deaccent_o_0']          = 'pois';
$lang['deaccent_o_1']          = 'Poista aksenttimerkit';
$lang['deaccent_o_2']          = 'translitteroi';
$lang['gdlib_o_0']             = 'GD Lib ei ole saatavilla';
$lang['gdlib_o_1']             = 'Versio 1.x';
$lang['gdlib_o_2']             = 'Automaattitunnistus';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Yhteenveto';
$lang['rss_content_o_diff']    = 'Yhdistetty erot';
$lang['rss_content_o_htmldiff'] = 'HTML muotoiltu erot lista';
$lang['rss_content_o_html']    = 'Täysi HTML-sivu';
$lang['rss_linkto_o_diff']     = 'erot-näkymä';
$lang['rss_linkto_o_page']     = 'muutettu sivu';
$lang['rss_linkto_o_rev']      = 'versiolista';
$lang['rss_linkto_o_current']  = 'nykyinen sivu';
$lang['compression_o_0']       = 'ei mitään';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'älä käytä';
$lang['xsendfile_o_1']         = 'Oma lighttpd otsikko (ennen 1.5 julkaisua)';
$lang['xsendfile_o_2']         = 'Standardi X-sendfile header';
$lang['xsendfile_o_3']         = 'Oma Nginx X-Accel-Redirect header';
$lang['showuseras_o_loginname'] = 'Kirjautumisnimi';
$lang['showuseras_o_username'] = 'Käyttäjän koko nimi';
$lang['showuseras_o_email']    = 'Käyttäjän sähköpostiosoite. (sumennettu mailguard asetusten mukaisesti)';
$lang['showuseras_o_email_link'] = 'Käyttäjän sähköpostiosoite mailto: linkkinä';
$lang['useheading_o_0']        = 'Ei koskaan';
$lang['useheading_o_navigation'] = 'Vain Navigointi';
$lang['useheading_o_content']  = 'Vain Wiki Sisältö';
$lang['useheading_o_1']        = 'Aina';
